@@ -4,7 +4,7 @@ from deep_utils.dummy_objects.dummy_framework import LazyModule
 from .utils.lib_utils.integeration_utils import import_lazy_module
 
 # Deep Utils version number
-__version__ = "1.5.1"
+__version__ = "1.5.6"
 
 from .utils.constants import DUMMY_PATH, Backends
 
@@ -41,7 +41,8 @@ _import_structure = {
     "utils.prompt_utils.prompt_utils": ["PromptUtils"],
     "utils.ff_utils.ffprobe_utils": ["FFProbeUtils"],
     "utils.datetime_utils.datetime_utils": ["DateTimeUtils"],
-
+    "utils.youtube_download.download_youtube": ["DownloadYoutube"],
+    "medical.dicom2nifti_utils.dicom2nifti_utils":["Dicom2Nifti"],
     DUMMY_PATH: [],  # this is required for dummy check!
 }
 
@@ -159,6 +160,8 @@ if TYPE_CHECKING:
     from .utils.boto3_utils.boto3_utils import Boto3Utils
     from .utils.ff_utils.ffprobe_utils import FFProbeUtils
     from .utils.datetime_utils.datetime_utils import DateTimeUtils
+    from .utils.youtube_download.download_youtube import DownloadYoutube
+    from .medical.dicom2nifti_utils.dicom2nifti_utils import Dicom2Nifti
 else:
     import sys
 
