@@ -10,7 +10,8 @@ class Backends(str, Enum):
     All required dependency packages and libraries. Note that the values here must be the exact module names used
     for importing, for example if you set PILLOW the value must be `PIL` not `pillow`, `pil`, etc.
     """
-
+    MINIO = "minio"
+    BOTO3 = "boto3"
     NUMPY = "numpy"
     TORCH = "torch"
     TRANSFORMERS = "transformers"
@@ -41,6 +42,8 @@ class Backends(str, Enum):
     AIOHTTP = "aiohttp"
     NIBABEL = "nibabel"
     TORCHAUDIO = "torchaudio"
+    TikToken = "tiktoken"
+    DECORD = "decord"
 
     def __str__(self):
         return str(self.value)
